# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2018-01-15 18:54
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simple_feedback', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='meta',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict),
        ),
    ]
